/**
 * Copyright (C) 2012-2019 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public
 * License version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 */
package org.n52.sos.ds.hibernate.util;

import org.joda.time.DateTime;
import org.n52.sos.ogc.gml.time.Time;
import org.n52.sos.ogc.gml.time.TimeInstant;
import org.n52.sos.ogc.gml.time.TimePeriod;

/**
 * Holder for observation time extrema. Contains phenomenon, result and valid
 * time.
 * 
 * @author Carsten Hollmann <c.hollmann@52north.org>
 * @since 4.3.0
 *
 */
public class ObservationTimeExtrema extends TimeExtrema {

    private DateTime minValidTime;

    private DateTime maxValidTime;

    public DateTime getMinValidTime() {
        return minValidTime;
    }

    public void setMinValidTime(DateTime minValidTime) {
        this.minValidTime = minValidTime;
    }

    public DateTime getMaxValidTime() {
        return maxValidTime;
    }

    public void setMaxValidTime(DateTime maxValidTime) {
        this.maxValidTime = maxValidTime;
    }

    public Time getValidTime() {
        if (isSetValidTime()) {
            if (getMinValidTime().equals(getMaxValidTime())) {
                return new TimeInstant(getMaxValidTime());
            }
            return new TimePeriod(getMinValidTime(), getMaxValidTime());
        }
        return null;
    }

    public boolean isSetValidTime() {
        return getMinValidTime() != null && getMaxValidTime() != null;
    }

    public boolean isEmpty() {
        return !isSetPhenomenonTimes() && !isSetResultTimes() && !isSetValidTime();
    }

    public void expand(ObservationTimeExtrema ote) {
        if (isEmpty() && !ote.isEmpty()) {
            setMinPhenomenonTime(ote.getMinPhenomenonTime());
            setMaxPhenomenonTime(ote.getMaxPhenomenonTime());
            setMinResultTime(ote.getMinResultTime());
            setMaxResultTime(ote.getMaxResultTime());
            setMinValidTime(ote.getMinValidTime());
            setMaxValidTime(ote.getMaxValidTime());
        } else {
            setMinPhenomenonTime(getMinPhenomenonTime().isAfter(ote.getMinPhenomenonTime()) ? ote.getMinPhenomenonTime() : getMinPhenomenonTime());
            setMaxPhenomenonTime(getMaxPhenomenonTime().isBefore(ote.getMaxPhenomenonTime()) ? ote.getMaxPhenomenonTime() : getMaxPhenomenonTime());
            setMinResultTime(getMinResultTime().isAfter(ote.getMinResultTime()) ? ote.getMinResultTime() : getMinResultTime());
            setMaxResultTime(getMaxResultTime().isBefore(ote.getMaxResultTime()) ? ote.getMaxResultTime() : getMaxResultTime());
            setMinValidTime(getMinValidTime().isAfter(ote.getMinValidTime()) ? ote.getMinValidTime() : getMinValidTime());
            setMaxValidTime(getMaxValidTime().isBefore(ote.getMaxValidTime()) ? ote.getMaxValidTime() : getMaxValidTime());
        }
    }

}
